@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::Simple;
 # ABSTRACT: simple parsing of RFC2822 message format and headers
-$Email::Simple::VERSION = '2.213';
+$Email::Simple::VERSION = '2.216';
 use Carp ();
 
 use Email::Simple::Creator;
@@ -39,9 +39,9 @@ sub __crlf_re { qr/\x0a\x0d|\x0d\x0a|\x0a|\x0d/; }
 #pod       ],
 #pod       body => '...',
 #pod   );
-#pod   
+#pod
 #pod   $email->header_set( 'X-Content-Container' => 'bottle/glass' );
-#pod   
+#pod
 #pod   print $email->as_string;
 #pod
 #pod =head1 DESCRIPTION
@@ -237,6 +237,13 @@ sub header_obj_set {
 #pod
 #pod This is another name (and the preferred one) for C<header_set>.
 #pod
+#pod =method header_raw_prepend
+#pod
+#pod   $email->header_raw_prepend($field => $value);
+#pod
+#pod This method adds a new instance of the name field as the first field in the
+#pod header.
+#pod
 #pod =method header_names
 #pod
 #pod     my @header_names = $email->header_names;
@@ -267,6 +274,7 @@ BEGIN {
   for my $method (qw(
     header_raw header
     header_raw_set header_set
+    header_raw_prepend
     header_raw_pairs header_pairs
     header_names
   )) {
@@ -340,7 +348,7 @@ Email::Simple - simple parsing of RFC2822 message format and headers
 
 =head1 VERSION
 
-version 2.213
+version 2.216
 
 =head1 SYNOPSIS
 
@@ -367,9 +375,9 @@ version 2.213
       ],
       body => '...',
   );
-  
+
   $email->header_set( 'X-Content-Container' => 'bottle/glass' );
-  
+
   print $email->as_string;
 
 =head1 DESCRIPTION
@@ -454,6 +462,13 @@ This is another name (and the preferred one) for C<header>.
 
 This is another name (and the preferred one) for C<header_set>.
 
+=head2 header_raw_prepend
+
+  $email->header_raw_prepend($field => $value);
+
+This method adds a new instance of the name field as the first field in the
+header.
+
 =head2 header_names
 
     my @header_names = $email->header_names;
@@ -526,7 +541,7 @@ Ricardo SIGNES
 
 =head1 CONTRIBUTORS
 
-=for stopwords Brian Cassidy Christian Walde Michael Stevens Pali Ricardo SIGNES Ronald F. Guilmette William Yardley
+=for stopwords Brian Cassidy Christian Walde Marc Bradshaw Michael Stevens Pali Ricardo SIGNES Ronald F. Guilmette William Yardley
 
 =over 4
 
@@ -540,6 +555,10 @@ Christian Walde <walde.christian@googlemail.com>
 
 =item *
 
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
 Michael Stevens <mstevens@etla.org>
 
 =item *
