@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Simple::Header;
 # ABSTRACT: the header of an Email::Simple message
-$Email::Simple::Header::VERSION = '2.213';
+$Email::Simple::Header::VERSION = '2.216';
 use Carp ();
 
 require Email::Simple;
@@ -283,6 +283,29 @@ sub header_set {
   $self->header_raw_set($field, @data);
 }
 
+#pod =method header_raw_prepend
+#pod
+#pod   $header->header_raw_prepend($field => $value);
+#pod
+#pod This method adds a new instance of the name field as the first field in the
+#pod header.
+#pod
+#pod =cut
+
+sub header_raw_prepend {
+  my ($self, $field, $value) = @_;
+
+  Carp::confess("tried to prepend raw header with undefined field name")
+    unless defined $field;
+
+  Carp::confess(qq{tried to prepend raw header "$field" with undefined value})
+    unless defined $value;
+
+  unshift @{ $self->{headers} }, $field => $value;
+
+  return;
+}
+
 #pod =method crlf
 #pod
 #pod This method returns the newline string used in the header.
@@ -292,18 +315,18 @@ sub header_set {
 sub crlf { $_[0]->{mycrlf} }
 
 # =method fold
-# 
+#
 #   my $folded = $header->fold($line, \%arg);
-# 
+#
 # Given a header string, this method returns a folded version, if the string is
 # long enough to warrant folding.  This method is used internally.
-# 
+#
 # Valid arguments are:
-# 
+#
 #   at      - fold lines to be no longer than this length, if possible
 #             if given and false, never fold headers
 #   indent  - indent lines with this string
-# 
+
 # =cut
 
 sub _fold {
@@ -312,17 +335,30 @@ sub _fold {
 
   $arg->{at} = $self->_default_fold_at unless exists $arg->{at};
 
+  $arg->{indent} = $self->_default_fold_indent unless exists $arg->{indent};
+
+  my $indent = $arg->{indent} || $self->_default_fold_indent;
+
+  # We will not folder headers if...
+  # * the header has vertical whitespace
+  # * all vertical whitespace is followed by horizontal whitespace or END
+  if ($line =~ /\n/) {
+    if ($line =~ s/\n([^\s\t])/\n$indent$1/g) {
+      Carp::carp("bad space in header: newline followed by non-space: $line");
+    } else {
+      $line .= $self->crlf unless $line =~ /\n$/;
+      return $line;
+    }
+  }
+
   return $line . $self->crlf unless $arg->{at} and $arg->{at} > 0;
 
   my $limit  = ($arg->{at} || $self->_default_fold_at) - 1;
 
   return $line . $self->crlf if length $line <= $limit;
 
-  $arg->{indent} = $self->_default_fold_indent unless exists $arg->{indent};
-
-  my $indent = $arg->{indent} || $self->_default_fold_indent;
-
   return $self->__fold_objless($line, $limit, $indent, $self->crlf);
+
 }
 
 sub __fold_objless {
@@ -345,19 +381,19 @@ sub __fold_objless {
 }
 
 # =method default_fold_at
-# 
+#
 # This method (provided for subclassing) returns the default length at which to
 # try to fold header lines.  The default default is 78.
-# 
+#
 # =cut
 
 sub _default_fold_at { 78 }
 
 # =method default_fold_indent
-# 
+#
 # This method (provided for subclassing) returns the default string used to
 # indent folded headers.  The default default is a single space.
-# 
+#
 # =cut
 
 sub _default_fold_indent { " " }
@@ -376,7 +412,7 @@ Email::Simple::Header - the header of an Email::Simple message
 
 =head1 VERSION
 
-version 2.213
+version 2.216
 
 =head1 SYNOPSIS
 
@@ -463,6 +499,13 @@ better to be explicit and use L<header_raw_set>.  (In Email::MIME,
 L<header_str_set> exists for letting the library do the header encoding for
 you.)
 
+=head2 header_raw_prepend
+
+  $header->header_raw_prepend($field => $value);
+
+This method adds a new instance of the name field as the first field in the
+header.
+
 =head2 crlf
 
 This method returns the newline string used in the header.
